@@ -1,7 +1,9 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
+#![cfg_attr(feature = "dox", feature(doc_cfg))]
 #![doc = include_str!("../README.md")]
 
+pub use ffi;
 pub use gdk;
 
 mod wayland_device;
